@@ -44,19 +44,19 @@ def create_training_job(local_data, source_code, weights, hyper_param):
     # upload data and code to s3
     # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html
     if local_data is not None:
-        #__upload_one_folder(job_id, FileType.Traindata.name, local_data)
+        __upload_one_folder(job_id, FileType.Traindata.name, local_data)
         print(f"uploaded {local_data}")
     else:
         print("local_data already exists")
 
     if source_code is not None:
-        #__upload_one_file(job_id, FileType.Code.name, source_code)
+        __upload_one_file(job_id, FileType.Code.name, source_code)
         print(f"uploaded {source_code}")
     else:
         print("source_code already exists")
 
     if weights is not None:
-        #__upload_one_file(job_id, FileType.Weights.name, weights)
+        __upload_one_file(job_id, FileType.Weights.name, weights)
         print(f"uploaded {weights}")
     else:
         print("weights already exists")
@@ -187,6 +187,6 @@ if __name__ == "__main__":
     #getFloderFiles("test")
     #print(files)
     make_tar("yolov5")
-    create_training_job("none", "none", "none", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
+    create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
     #make_tar("train.py")
     #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
